==> nextcloud-24.0.6.tar.bz2: nextcloud/apps/viewer/l10n/fr.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visionneuse",
    "Simple file viewer with slideshow for media" : "Visionneuse simple de fichiers avec diaporama pour les médias",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Montrez vos dernières photos et vidéos de vacances comme au cinéma, montrez un aperçu de votre dernier roman directement depuis votre Nextcloud, choisissez le meilleur GIF de votre collection grâce à l'aperçu direct de vos fichiers favoris et bien d'autres choses encore !",
    "Your browser does not support audio." : "Votre navigateur web ne prend pas en charge l'audio.",
    "Error loading {name}" : "Erreur au chargement de {name}",
    "Image saved" : "Image sauvegardée",
    "Error saving image" : "Erreur lors de l'enregistrement de l'image",
    "Unsaved changes" : "Modifications non enregistrées",
    "Drop changes" : "Abandonner les changements",
    "Content of \"{fileName}\"" : "Contenu de \"{filename}\"",
    "Your browser does not support videos." : "Votre navigateur ne prend pas en charge les vidéos.",
    "Edit" : "Modifier",
    "Open sidebar" : "Ouvrir la barre latérale",
    "Download" : "Télécharger",
    "Delete" : "Supprimer",
    "There is no plugin available to display this file type" : "Il n'y a pas d'extension disponible pour afficher ce type de fichier.",
    "View" : "Afficher",
    "Name" : "Nom",
    "Save" : "Enregistrer",
    "Save as" : "Enregistrer sous",
    "Back" : "Retour",
    "Loading …" : "Chargement …",
    "Reset" : "Réinitialiser",
    "All changes will be lost." : "Tous les changements seront perdus.",
    "Are you sure you want to continue?" : "Êtes-vous sûr de vouloir continuer ?",
    "Cancel" : "Annuler",
    "Continue" : "Continuer",
    "Undo" : "Annuler",
    "Redo" : "Rétablir",
    "Show original image" : "Afficher l'image originale",
    "Zoom in" : "Zoomer",
    "Zoom out" : "Dézoomer",
    "Toggle zoom menu" : "Afficher / Masquer le menu de zoom",
    "Adjust" : "Ajuster",
    "Fine-tune" : "Réglages fins",
    "Filters" : "Filtres",
    "Watermark" : "Filigrane",
    "Draw" : "Dessiner",
    "Resize" : "Redimensionner",
    "Invalid image." : "Image invalide.",
    "Error while uploading the image." : "Erreur lors du téléversement de l'image",
    "are not images" : "ne sont pas des images",
    "is not an image" : "n'est pas une image",
    "to be uploaded" : "à téléverser",
    "Crop" : "Recadrer",
    "Original" : "Original",
    "Custom" : "Personnalisé",
    "Square" : "Carré",
    "Landscape" : "Paysage",
    "Portrait" : "Portrait",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Télévision Classique",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flèche",
    "Blur" : "Flou",
    "Brightness" : "Luminosité",
    "Contrast" : "Contraste",
    "Un-flip X" : "Suppr. miroir horiz.",
    "Flip X" : "Miroir horiz.",
    "Un-flip Y" : "Suppr. miroir vertic.",
    "Flip Y" : "Miroir vertic.",
    "HSV" : "TSV",
    "Hue" : "Teinte",
    "Saturation" : "Saturation",
    "Value" : "Valeur",
    "Image" : "Image",
    "Importing …" : "Importation...",
    "+ Add image" : "+ Ajouter une image",
    "Line" : "Ligne",
    "Pen" : "Stylo",
    "Polygon" : "Polygone",
    "Sides" : "Diapositives",
    "Rectangle" : "Rectangle",
    "Corner Radius" : "Rayon d'angle",
    "Width in pixels" : "Largeur en pixels",
    "Height in pixels" : "Hauteur en pixels",
    "Toggle ratio lock" : "Activer / Désactiver la conservation des proportions",
    "Reset to original image size" : "Rétablir la taille originale de l'image",
    "Rotate" : "Faire pivoter",
    "Text" : "Texte",
    "Text spacing" : "Espacement du texte",
    "Text alignment" : "Alignement du texte",
    "Font family" : "Police de caractère",
    "Size" : "Taille",
    "Letter spacing" : "Espacement des caractères",
    "Line height" : "Hauteur de ligne",
    "Warmth" : "Température",
    "+ Add watermark" : "+ Ajouter un filigrane",
    "Choose watermark type" : "Choisir un type de filigrane",
    "Upload watermark" : "Téléverser un filigrane",
    "Add as text" : "Ajouter comme texte",
    "Padding" : "Marge interne",
    "Shadow" : "Ombre",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacité",
    "Position" : "Position",
    "Stroke" : "Coutour",
    "Save image as" : "Enregistrer l'image sous",
    "Extension" : "Extension",
    "Name is required." : "Le nom est obligatoire.",
    "Quality" : "Qualité",
    "Saved image size (width x height)" : "Taille de l'image sauvegardée (largeur x hauteur)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Notez que la zone de recadrage sélectionnée est inférieure au redimensionnement appliqué, ce qui peut entraîner une baisse de qualité.",
    "Actual size (100%)" : "Taille actuelle (100%)",
    "Fit size" : "Adapter à la taille",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Affichez vos dernières photos et vidéos de vacances comme dans les films, visionnez votre dernier roman directement depuis Nextcloud, choisissez le meilleur GIF de votre collection grâce à la prévisualisation directe de vos fichiers favoris et bien plus encore !"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");

==> nextcloud-30.0.11.tar.bz2: nextcloud/apps/viewer/l10n/fr.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Visionneuse",
    "Simple file viewer with slideshow for media" : "Visionneuse simple de fichiers avec diaporama pour les médias",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Montrez vos dernières photos et vidéos de vacances comme au cinéma, montrez un aperçu de votre dernier roman directement depuis votre Nextcloud, choisissez le meilleur GIF de votre collection grâce à l'aperçu direct de vos fichiers favoris et bien d'autres choses encore !",
    "Your browser does not support audio." : "Votre navigateur web ne prend pas en charge l'audio.",
    "Error loading {name}" : "Erreur au chargement de {name}",
    "Image saved" : "Image sauvegardée",
    "Error saving image" : "Erreur lors de l'enregistrement de l'image",
    "Unsaved changes" : "Modifications non enregistrées",
    "Drop changes" : "Abandonner les changements",
    "Play the live photo" : "Lire la live photo",
    "LIVE" : "EN DIRECT",
    "Your browser does not support videos." : "Votre navigateur ne prend pas en charge les vidéos.",
    "This file no longer exists" : "Ce fichier n'existe plus",
    "There is no plugin available to display this file type" : "Il n'y a pas d'extension disponible pour afficher ce type de fichier.",
    "Edit" : "Modifier",
    "Exit full screen" : "Quitter le plein écran",
    "Full screen" : "Plein écran",
    "Open sidebar" : "Ouvrir le panneau latéral",
    "Download" : "Télécharger",
    "Delete" : "Supprimer",
    "View" : "Afficher",
    "Name" : "Nom",
    "Save" : "Enregistrer",
    "Save as" : "Enregistrer sous",
    "Back" : "Retour",
    "Loading …" : "Chargement …",
    "Reset" : "Réinitialiser",
    "All changes will be lost." : "Tous les changements seront perdus.",
    "Are you sure you want to continue?" : "Êtes-vous sûr de vouloir continuer ?",
    "Cancel" : "Annuler",
    "Apply" : "Appliquer",
    "Warning" : "Avertissement",
    "Confirm" : "Confirmer",
    "Discard changes" : "Abandonner les modifications",
    "Undo" : "Annuler",
    "Redo" : "Rétablir",
    "Show original image" : "Afficher l'image originale",
    "Zoom in" : "Zoomer",
    "Zoom out" : "Dézoomer",
    "Toggle zoom menu" : "Afficher/Masquer le menu de zoom",
    "Adjust" : "Ajuster",
    "Fine-tune" : "Réglages fins",
    "Filters" : "Filtres",
    "Watermark" : "Filigrane",
    "Draw" : "Dessiner",
    "Resize" : "Redimensionner",
    "Image name" : "Nom de l'image",
    "Invalid image." : "Image invalide.",
    "Error while uploading the image." : "Erreur lors du téléversement de l'image",
    "are not images" : "ne sont pas des images",
    "is not an image" : "n'est pas une image",
    "to be uploaded" : "à téléverser",
    "Crop" : "Recadrer",
    "Original" : "Original",
    "Custom" : "Personnalisé",
    "Square" : "Carré",
    "Landscape" : "Paysage",
    "Portrait" : "Portrait",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Télévision Classique",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Flèche",
    "Blur" : "Flou",
    "Brightness" : "Luminosité",
    "Contrast" : "Contraste",
    "Un-flip X" : "Suppr. miroir horiz.",
    "Flip X" : "Miroir horiz.",
    "Un-flip Y" : "Suppr. miroir vertic.",
    "Flip Y" : "Miroir vertic.",
    "HSV" : "TSV",
    "Hue" : "Teinte",
    "Saturation" : "Saturation",
    "Value" : "Valeur",
    "Image" : "Image",
    "Importing …" : "Importation...",
    "+ Add image" : "+ Ajouter une image",
    "Upload image" : "Téléversement d'image",
    "From gallery" : "De la galerie",
    "Line" : "Ligne",
    "Pen" : "Stylo",
    "Polygon" : "Polygone",
    "Sides" : "Diapositives",
    "Rectangle" : "Rectangle",
    "Corner Radius" : "Rayon d'angle",
    "Width in pixels" : "Largeur en pixels",
    "Height in pixels" : "Hauteur en pixels",
    "Toggle ratio lock" : "Activer/Désactiver la conservation des proportions",
    "Reset to original image size" : "Rétablir la taille originale de l'image",
    "Rotate" : "Faire pivoter",
    "Text" : "Texte",
    "Text spacing" : "Espacement du texte",
    "Text alignment" : "Alignement du texte",
    "Font family" : "Police de caractère",
    "Size" : "Taille",
    "Letter spacing" : "Espacement des caractères",
    "Line height" : "Hauteur de ligne",
    "Warmth" : "Température",
    "+ Add watermark" : "+ Ajouter un filigrane",
    "+ Add text watermark" : "+ Ajouter un texte filigraner",
    "Choose watermark type" : "Choisir un type de filigrane",
    "Upload watermark" : "Téléverser un filigrane",
    "Add as text" : "Ajouter comme texte",
    "Padding" : "Marge interne",
    "Paddings" : "Paddings",
    "Shadow" : "Ombre",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertical",
    "Opacity" : "Opacité",
    "Transparency" : "Transparence",
    "Position" : "Position",
    "Stroke" : "Coutour",
    "Save image as" : "Enregistrer l'image sous",
    "Extension" : "Extension",
    "Format" : "Format",
    "Name is required." : "Le nom est obligatoire.",
    "Quality" : "Qualité",
    "Saved image size (width x height)" : "Taille de l'image sauvegardée (largeur x hauteur)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Notez que la zone de recadrage sélectionnée est inférieure au redimensionnement appliqué, ce qui peut entraîner une baisse de qualité.",
    "Actual size (100%)" : "Taille actuelle (100%)",
    "Fit size" : "Adapter à la taille",
    "Select image to add …" : "Sélectionnez l'image à ajouter …",
    "Failed to load image." : "Échec du chargement de l'image.",
    "Menu" : "Menu",
    "Width" : "Largeur",
    "Height" : "Taille",
    "No preview available for this crop item" : "Aucun aperçu disponible pour cet élément de recadrage"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
